@@ -5,15 +5,29 @@ PY2 = sys.version_info[0] == 2
 PY3 = sys.version_info[0] == 3
 PYPY = '__pypy__' in sys.builtin_module_names
 
-supportskwordered = PY >= (3,6) or PYPY
-supportscompiler = PY >= (3,6)
-supportsintenum = PY >= (3,4)
-supportsintflag = PY >= (3,6)
 try:
     import numpy
     supportsnumpy = True
 except ImportError:
     supportsnumpy = False
+try:
+    import ruamel.yaml
+    assert PY3
+    supportsksyexport = True
+except (ImportError, AssertionError):
+    supportsksyexport = False
+try:
+    from enum import IntEnum
+    supportsintenum = True
+except ImportError:
+    supportsintenum = False
+try:
+    from enum import IntFlag
+    supportsintflag = True
+except ImportError:
+    supportsintflag = False
+
+supportskwordered = PY >= (3,6) or PYPY
 
 
 if PY3:
@@ -64,12 +78,30 @@ if PY3:
         """Iterates though b'...' string yielding (0 through 255) integers."""
         return data
 
-    def reprbytes(data):
-        """Trims b- prefix and both apostrophies."""
+    def reprstring(data):
+        """Ensures there is b- u- prefix before the string."""
         if isinstance(data, bytes):
-            return repr(data)[2:-1]
+            return repr(data)
         if isinstance(data, str):
-            return repr(data)[1:-1]
+            return 'u' + repr(data)
+
+    def trimstring(data):
+        """Trims b- u- prefix"""
+        if isinstance(data, bytes):
+            return repr(data)[1:]
+        if isinstance(data, str):
+            return repr(data)
+
+    import builtins
+    bytes = builtins.bytes
+
+    def integers2bytes(ints):
+        """Converts integer generator into bytes."""
+        return bytes(ints)
+
+    def bytes2integers(data):
+        """Converts bytes into bytes/bytearray, so indexing/iterating yields integers."""
+        return data
 
 
 else:
@@ -116,11 +148,33 @@ else:
 
     def iterateints(data):
         """Iterates though b'...' string yielding (0 through 255) integers."""
-        return (ord(c) for c in data)
+        return bytearray(data)
 
-    def reprbytes(data):
-        """Trims b- prefix and both apostrophies."""
+    def reprstring(data):
+        """Ensures there is b- u- prefix before the string."""
         if isinstance(data, str):
-            return repr(data)[1:-1]
+            return 'b' + repr(data)
         if isinstance(data, unicode):
-            return repr(data)[2:-1]
+            return repr(data)
+
+    def trimstring(data):
+        """Trims b- u- prefix"""
+        if isinstance(data, str):
+            return repr(data)
+        if isinstance(data, unicode):
+            return repr(data)[1:]
+
+    def bytes(countorseq=0):
+        """Backports bytes() from PY3."""
+        if isinstance(countorseq, integertypes):
+            return b"\x00" * countorseq
+        else:
+            return b"".join(chr(x) for x in countorseq)
+
+    def integers2bytes(ints):
+        """Converts integer generator into bytes."""
+        return bytes(bytearray(ints))
+
+    def bytes2integers(data):
+        """Converts bytes into bytes/bytearray, so indexing/iterating yields integers."""
+        return bytearray(data)
